summary refs log tree commit diff
path: root/pkgs/development/python-modules/telfhash/telfhash-new-tlsh-hash.patch
blob: 3984a4c1e810204260aea0fa25b0ae5deb8ed290 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
diff --git a/telfhash/telfhash.py b/telfhash/telfhash.py
index f2bbd25..c6e346c 100755
--- a/telfhash/telfhash.py
+++ b/telfhash/telfhash.py
@@ -132,7 +132,7 @@ def get_hash(symbols_list):
     symbol_string = ",".join(symbols_list)
     encoded_symbol_string = symbol_string.encode("ascii")
 
-    return tlsh.forcehash(encoded_symbol_string).lower()
+    return tlsh.forcehash(encoded_symbol_string)
 
 
 def elf_get_imagebase(elf):
diff --git a/telfhash/grouping.py b/telfhash/grouping.py
index c62f8d9..4ee9f0b 100644
--- a/telfhash/grouping.py
+++ b/telfhash/grouping.py
@@ -32,10 +32,10 @@ import tlsh
 def get_combination(telfhash_data):
 
     #
     # TLSH hash is 70 characters long. if the telfhash is not 70
     # characters in length, exclude from the list
     #
-    files_list = [x for x in list(telfhash_data.keys()) if telfhash_data[x]["telfhash"] is not None and len(telfhash_data[x]["telfhash"]) == 70]
+    files_list = [x for x in list(telfhash_data.keys()) if telfhash_data[x]["telfhash"] is not None and len(telfhash_data[x]["telfhash"]) == 72]
 
     #
     # get the combination of all the possible pairs of filenames
@@ -32,10 +32,10 @@ import tlsh
 
     #
-    # TLSH hash is 70 characters long. if the telfhash is not 70
+    # The new TLSH hash is 72 characters long. if the telfhash is not 72
     # characters in length, exclude from the list
     #